@@ -3,20 +3,20 @@ package Specio::Constraint::Enum;
 use strict;
 use warnings;
 
-our $VERSION = '0.47';
+our $VERSION = '0.49';
 
+use Clone ();
 use Role::Tiny::With;
 use Scalar::Util qw( refaddr );
 use Specio::Library::Builtins;
 use Specio::OO;
-use Storable qw( dclone );
 
 use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( parent _inline_generator )) {
@@ -86,7 +86,7 @@ Specio::Constraint::Enum - A class for constraints which require a string matchi
 
 =head1 VERSION
 
-version 0.47
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -127,8 +127,6 @@ L<Specio::Role::Inlinable> roles.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -139,7 +137,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2021 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
