@@ -3,18 +3,18 @@ package Specio::Constraint::Parameterized;
 use strict;
 use warnings;
 
-our $VERSION = '0.46';
+our $VERSION = '0.49';
 
+use Clone ();
 use Role::Tiny::With;
 use Specio::OO;
-use Storable qw( dclone );
 
 use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     $attrs->{parent}{isa}      = 'Specio::Constraint::Parameterizable';
@@ -80,7 +80,7 @@ Specio::Constraint::Parameterized - A class which represents parameterized const
 
 =head1 VERSION
 
-version 0.46
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -110,8 +110,8 @@ This class's constructor accepts two additional parameters:
 
 =item * parent
 
-This should be the L<Specio::Constraint::Parameterizable> object from which this
-object was created.
+This should be the L<Specio::Constraint::Parameterizable> object from which
+this object was created.
 
 This parameter is required.
 
@@ -132,8 +132,6 @@ Returns the type that was passed to the constructor.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -144,7 +142,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2020 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
