@@ -3,11 +3,11 @@ package Specio::Constraint::Role::CanType;
 use strict;
 use warnings;
 
-our $VERSION = '0.44';
+our $VERSION = '0.49';
 
-use Scalar::Util qw( blessed );
+use Clone               ();
+use Scalar::Util        qw( blessed );
 use Specio::PartialDump qw( partial_dump );
-use Storable qw( dclone );
 
 use Role::Tiny;
 
@@ -16,7 +16,7 @@ with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( parent _inline_generator )) {
@@ -41,7 +41,7 @@ sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
 
-    my $type          = ( split /::/, blessed $self)[-1];
+    my $type          = ( split /::/, blessed $self )[-1];
     my @methods       = @{ $self->methods };
     my $all_word_list = _word_list(@methods);
     my $allow_classes = $self->_allow_classes;
@@ -144,18 +144,17 @@ Specio::Constraint::Role::CanType - Provides a common implementation for Specio:
 
 =head1 VERSION
 
-version 0.44
+version 0.49
 
 =head1 DESCRIPTION
 
-See L<Specio::Constraint::AnyCan> and L<Specio::Constraint::ObjectCan> for details.
+See L<Specio::Constraint::AnyCan> and L<Specio::Constraint::ObjectCan> for
+details.
 
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -166,7 +165,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
