@@ -3,19 +3,20 @@ package Specio::Constraint::Role::DoesType;
 use strict;
 use warnings;
 
-our $VERSION = '0.47';
+our $VERSION = '0.49';
+
+use Clone               ();
+use Scalar::Util        qw( blessed );
+use Specio::PartialDump qw( partial_dump );
 
 use Role::Tiny;
-use Scalar::Util qw( blessed );
-use Specio::PartialDump qw( partial_dump );
-use Storable qw( dclone );
 
 use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( parent _inline_generator )) {
@@ -40,7 +41,7 @@ sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
 
-    my $type          = ( split /::/, blessed $self)[-1];
+    my $type          = ( split /::/, blessed $self )[-1];
     my $role          = $self->role;
     my $allow_classes = $self->_allow_classes;
 
@@ -58,7 +59,7 @@ sub _wrap_message_generator {
                     "An unblessed reference ($dump) will never pass an $type check (wants $role)";
             }
 
-            if ( !blessed $value) {
+            if ( !blessed $value ) {
                 return
                     "An empty string will never pass an $type check (wants $role)"
                     unless length $value;
@@ -109,7 +110,7 @@ Specio::Constraint::Role::DoesType - Provides a common implementation for Specio
 
 =head1 VERSION
 
-version 0.47
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -120,8 +121,6 @@ details.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -132,7 +131,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2021 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
