@@ -3,7 +3,7 @@ package Specio::Constraint::Simple;
 use strict;
 use warnings;
 
-our $VERSION = '0.44';
+our $VERSION = '0.49';
 
 use Role::Tiny::With;
 use Specio::OO;
@@ -28,7 +28,7 @@ Specio::Constraint::Simple - Class for simple (non-parameterized or specialized)
 
 =head1 VERSION
 
-version 0.44
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -126,9 +126,9 @@ This environment will be used when compiling the constraint as part of a
 subroutine. The named variables will be captured as closures in the generated
 subroutine, using L<Eval::Closure>.
 
-It should be very rare to need to set this in the constructor. It's more
-likely that a special type subclass would need to provide values that it
-generates internally.
+It should be very rare to need to set this in the constructor. It's more likely
+that a special type subclass would need to provide values that it generates
+internally.
 
 If you do set this, you are responsible for generating variable names that
 won't clash with anything else in the inlined code.
@@ -140,11 +140,11 @@ This parameter defaults to an empty hash reference.
 A subroutine to generate an error message when the type check fails. The
 default message says something like "Validation failed for type named Int
 declared in package Specio::Library::Builtins
-(.../Specio/blib/lib/Specio/Library/Builtins.pm) at line 147 in sub named (eval)
-with value 1.1".
+(.../Specio/blib/lib/Specio/Library/Builtins.pm) at line 147 in sub named
+(eval) with value 1.1".
 
-You can override this to provide something more specific about the way the
-type failed.
+You can override this to provide something more specific about the way the type
+failed.
 
 The subroutine you provide will be called as a subroutine, I<not as a method>,
 with two arguments. The first is the description of the type (the bit in the
@@ -227,8 +227,8 @@ anonymous the name will be "anonymous type".
 This is a unique id for the type as a string. This is useful if you need to
 make a hash key based on a type, for example. This should be treated as an
 essentially arbitrary and opaque string, and could change at any time in the
-future. If you want something human-readable, use the C<< $type->description
->> method.
+future. If you want something human-readable, use the C<< $type->description >>
+method.
 
 =head2 $type->add_coercion($coercion)
 
@@ -264,8 +264,7 @@ second is a hash reference containing variables which need to be in scope for
 the code to work. This is intended to be passed to L<Eval::Closure>'s
 C<eval_closure> subroutine.
 
-The returned code is a single C<do { }> block without a terminating
-semicolon.
+The returned code is a single C<do { }> block without a terminating semicolon.
 
 =head2 $type->inline_assert($var)
 
@@ -295,8 +294,7 @@ second is a hash reference containing variables which need to be in scope for
 the code to work. This is intended to be passed to L<Eval::Closure>'s
 C<eval_closure> subroutine.
 
-The returned code is a single C<do { }> block without a terminating
-semicolon.
+The returned code is a single C<do { }> block without a terminating semicolon.
 
 =head2 $type->inline_environment()
 
@@ -307,16 +305,34 @@ C<'@bar'>. The values are I<references> to a variable of the matching type.
 =head2 $type->coercion_sub
 
 This method returns a sub ref that takes a single argument and applied all
-relevant coercions to it. This sub ref will use L<Sub::Quote> if all the
-type's coercions are inlinable.
+relevant coercions to it. This sub ref will use L<Sub::Quote> if all the type's
+coercions are inlinable.
 
 This method exists primarily for the benefit of L<Moo>.
 
 =head1 OVERLOADING
 
-All constraints overloading subroutine de-referencing for the benefit of
-L<Moo>. The returned subroutine uses L<Sub::Quote> if the type constraint is
-inlinable.
+All constraints implement the following overloads:
+
+=head2 Subroutine De-referencing
+
+This is done for the benefit of L<Moo>. The returned subroutine uses
+L<Sub::Quote> if the type constraint is inlinable.
+
+=head2 Stringification
+
+For non-anonymous types, this will be the type's name. For anonymous types, a
+string like "__ANON__(Str)" is generated. However, this string should not be
+expected to be stable across releases, so don't use it for things like equality
+checks!
+
+=head2 Boolification
+
+This always returns true.
+
+=head2 String Equality (eq)
+
+This calls C<< $type->is_same_type_as($other) >> to compare the two types.
 
 =head1 ROLES
 
@@ -327,8 +343,6 @@ L<Specio::Role::Inlinable> roles.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -339,7 +353,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
