@@ -3,19 +3,19 @@ package Specio::Constraint::Union;
 use strict;
 use warnings;
 
-our $VERSION = '0.44';
+our $VERSION = '0.49';
 
-use List::Util qw( all any );
+use Clone;
+use List::Util 1.33 qw( all any );
 use Role::Tiny::With;
 use Specio::OO;
-use Storable qw( dclone );
 
 use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( _constraint _inline_generator )) {
@@ -133,7 +133,7 @@ Specio::Constraint::Union - A class for union constraints
 
 =head1 VERSION
 
-version 0.44
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -174,8 +174,6 @@ L<Specio::Role::Inlinable> roles.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -186,7 +184,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
