@@ -3,12 +3,11 @@ package Specio::Library::Structured;
 use strict;
 use warnings;
 
-our $VERSION = '0.46';
+our $VERSION = '0.49';
 
 use parent 'Specio::Exporter';
 
-use Carp qw( confess );
-use List::Util ();
+use Carp         qw( confess );
 use Scalar::Util qw( blessed );
 use Specio::Constraint::Structurable;
 use Specio::Declare;
@@ -84,7 +83,7 @@ Specio::Library::Structured - Structured types for Specio (Dict, Map, Tuple)
 
 =head1 VERSION
 
-version 0.46
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -115,26 +114,21 @@ version 0.46
 
 =head1 DESCRIPTION
 
-B<This particular library should be considered in an alpha state. The syntax
-for defining structured types may change, as well as some of the internals of
-its implementation.>
-
 This library provides a set of structured types for Specio, C<Dict>, C<Map>,
 and C<Tuple>. This library also exports two helper subs used for some types,
 C<optional> and C<slurpy>.
 
-All structured types are parameterized by calling C<< t( 'Type Name', of =>
-... ) >>. The arguments passed after C<of> vary for each type.
+All structured types are parameterized by calling C<< t( 'Type Name', of => ...
+) >>. The arguments passed after C<of> vary for each type.
 
 =head2 Dict
 
-A C<Dict> is a hashref with a well-defined set of keys and types for those
-key.
+A C<Dict> is a hashref with a well-defined set of keys and types for those key.
 
 The argument passed to C<of> should be a single hashref. That hashref must
-contain a C<kv> key defining the expected keys and the types for their
-values. This C<kv> value is itself a hashref. If a key/value pair is optional,
-use C<optional> around the I<type> for that key:
+contain a C<kv> key defining the expected keys and the types for their values.
+This C<kv> value is itself a hashref. If a key/value pair is optional, use
+C<optional> around the I<type> for that key:
 
     my $person = t(
         'Dict',
@@ -179,9 +173,9 @@ conceivably be any sort of value.
 
 A C<Tuple> is an arrayref with a fixed set of members in a specific order.
 
-The argument passed to C<of> should be a single arrayref consisting of
-types. You can mark a slot in the C<Tuple> as optional by wrapping the type in
-a call to C<optional>:
+The argument passed to C<of> should be a single arrayref consisting of types.
+You can mark a slot in the C<Tuple> as optional by wrapping the type in a call
+to C<optional>:
 
     my $record = t(
         'Tuple',
@@ -219,15 +213,13 @@ You cannot mix C<optional> and C<slurpy> in a C<Tuple> definition.
 =head1 LIMITATIONS
 
 Currently all structured types require that the types they are structured with
-can be inlined. This may change in the future, but inlining all your types is
-a really good idea, so you should do that anyway.
+can be inlined. This may change in the future, but inlining all your types is a
+really good idea, so you should do that anyway.
 
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -238,7 +230,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2020 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
