@@ -3,11 +3,11 @@ package Specio::Library::Structured::Dict;
 use strict;
 use warnings;
 
-our $VERSION = '0.45';
+our $VERSION = '0.49';
 
-use Carp qw( confess );
-use List::Util ();
-use Scalar::Util qw( blessed );
+use Carp            qw( confess );
+use List::Util 1.33 ();
+use Scalar::Util    qw( blessed );
 use Specio::Helpers qw( perlstring );
 use Specio::Library::Builtins;
 use Specio::TypeChecks qw( does_role );
@@ -22,7 +22,7 @@ sub _inline {
 }
 
 sub _parameterization_args_builder {
-    my $self = shift;
+    shift;
     my $args = shift;
 
     for my $p ( ( $args->{slurpy} || () ), values %{ $args->{kv} } ) {
@@ -77,7 +77,7 @@ sub _name_builder {
 }
 
 sub _structured_inline_generator {
-    my $self = shift;
+    shift;
     my $val  = shift;
     my %args = @_;
 
@@ -132,7 +132,7 @@ Specio::Library::Structured::Dict - Guts of Dict structured type
 
 =head1 VERSION
 
-version 0.45
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -144,8 +144,6 @@ There are no user facing parts here.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -156,7 +154,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2024 by Dave Rolsky.
 
 This is free software, licensed under:
 
